@@ -159,7 +159,6 @@ def tokenizeLines(
     indentChar: str | None = None
 
     for i, line in enumerate(lines):
-
         # Three kinds of "raw" elements, which prevent markdown processing inside of them.
         # 1. <pre> and manual opaque elements, which can contain markup and so can nest.
         # 2. <xmp>, <script>, and <style>, which contain raw text, can't nest.
@@ -392,8 +391,8 @@ def checkForMixedIndents(line: l.Line, indentChar: str) -> None:
             m.lint(f"Your document appears to use spaces to indent, but line {line.i} starts with tabs.")
         else:
             m.lint(f"Your document appears to use tabs to indent, but line {line.i} starts with spaces.")
-    if re.match(r"(\t+ )|( +\t)", line.text):
-        m.lint(f"Line {line.i} is indented with both tabs and spaces.")
+    if re.match(r"(\t+ +\t)|( +\t)", line.text):
+        m.lint(f"Line {line.i}'s indent contains tabs after spaces.")
 
 
 def prefixCount(text: str, numSpacesForIndentation: int) -> int:
